@@ -960,9 +960,10 @@ def verify_ocsp_response(cert, path, validation_context, cert_description=None,
             ))
             continue
 
+        retroactive = validation_context.retroactive_revinfo
         tolerance = validation_context.time_tolerance
 
-        if moment < cert_response['this_update'].native - tolerance:
+        if not retroactive and moment < cert_response['this_update'].native - tolerance:
             failures.append((
                 'OCSP response is from after the validation time',
                 ocsp_response
@@ -1461,13 +1462,16 @@ def verify_crl(cert, path, validation_context, use_deltas=True, cert_description
 
         # Check to make sure the CRL is valid for the moment specified
         tolerance = validation_context.time_tolerance
-        if moment < certificate_list['tbs_cert_list']['this_update'].native - tolerance:
+        retroactive = validation_context.retroactive_revinfo
+        crl_this_update = certificate_list['tbs_cert_list']['this_update'].native
+        if not retroactive and moment < crl_this_update - tolerance:
             failures.append((
                 'CRL is from after the validation time',
                 certificate_list
             ))
             continue
-        if moment > certificate_list['tbs_cert_list']['next_update'].native + tolerance:
+        crl_next_update = certificate_list['tbs_cert_list']['next_update'].native
+        if moment > crl_next_update + tolerance:
             failures.append((
                 'CRL should have been regenerated by the validation time',
                 certificate_list
@@ -1659,14 +1663,17 @@ def verify_crl(cert, path, validation_context, use_deltas=True, cert_description
                 ))
                 continue
 
-            if moment < delta_certificate_list['tbs_cert_list']['this_update'].native - tolerance:
+            retroactive = validation_context.retroactive_revinfo
+            crl_this_update = delta_certificate_list['tbs_cert_list']['this_update'].native
+            if not retroactive and moment < crl_this_update - tolerance:
                 failures.append((
                     'Delta CRL is from after the validation time',
                     certificate_list,
                     delta_certificate_list
                 ))
                 continue
-            if moment > delta_certificate_list['tbs_cert_list']['next_update'].native + tolerance:
+            crl_next_update = delta_certificate_list['tbs_cert_list']['next_update'].native
+            if moment > crl_next_update + tolerance:
                 failures.append((
                     'Delta CRL is from before the validation time',
                     certificate_list,
